Network | Static smooth curves - World Cup Network

## Dynamic Data - Neighbourhood Highlight

This example shows the power of the DataSet. Once a node is clicked, all nodes are greyed out except for the first and second order connected nodes. In this example we show how you can determine the order of connection per node as well as applying individual styling to the nodes based on whether or not they are connected to the selected node. The code doing the highlighting only takes about 1ms, the rest of the time is the redrawing of the network (9200 edges..).